@@ -38,19 +38,19 @@ def xirr(valuesPerDate):
     >>> xirr(valuesPerDate)
     -0.645363882724717
     '''
-    if not valuesPerDate or len(valuesPerDate) < 2:
+    if not valuesPerDate:
         return None
 
     if all(v >= 0 for v in valuesPerDate.values()):
-        return -float("inf")
-    if all(v <= 0 for v in valuesPerDate.values()):
         return float("inf")
+    if all(v <= 0 for v in valuesPerDate.values()):
+        return -float("inf")
 
     result = None
     try:
         result = scipy.optimize.newton(lambda r: xnpv(valuesPerDate, r), 0)
     except (RuntimeError, OverflowError):    # Failed to converge?
-        result = scipy.optimize.brentq(lambda r: xnpv(valuesPerDate, r), -0.999999999999999, 1e20)
+        result = scipy.optimize.brentq(lambda r: xnpv(valuesPerDate, r), -0.999999999999999, 1e20, maxiter=10**6)
 
     if not isinstance(result, complex):
         return result
